@@ -8,20 +8,10 @@ MainWindow::MainWindow(QWidget *parent) :
     ui->setupUi(this);
     ui->lineEdit->setValidator(new QDoubleValidator(0, 0, 2, this));
 
-    if (mvSettings.value("Currency1").isNull()) {
-        mvSettings.setValue("Currency1", "EUR");
-    }
-    if (mvSettings.value("Currency2").isNull()) {
-        mvSettings.setValue("Currency2", "USD");
-    }
-    if (mvSettings.value("TaxRate").isNull()) {
-        mvSettings.setValue("TaxRate", 20);
-    }
-    if (mvSettings.value("TipRate").isNull()) {
-        mvSettings.setValue("TipRate", 10);
-    }
+
 
     mvSettings.sync();
+    initialSettings();
     updateCurrency();
     updateButtons();
     mvTotal = 0;
@@ -46,6 +36,49 @@ void MainWindow::changeEvent(QEvent *e)
     }
 }
 
+void MainWindow::initialSettings()
+{
+    if (!mvSettings.contains("Currency1")) {
+        mvSettings.setValue("Currency1", "EUR");
+        mvSettings.setValue("Currency2", "USD");
+        mvSettings.setValue("TaxRate", 20);
+        mvSettings.setValue("TipRate", 10);
+        mvSettings.setValue("USD", 1.4374);
+        mvSettings.setValue("JPY", 130.76);
+        mvSettings.setValue("BGN", 1.9558);
+        mvSettings.setValue("CZK", 25.947);
+        mvSettings.setValue("DKK", 7.4420);
+        mvSettings.setValue("EEK", 15.6466);
+        mvSettings.setValue("GBP", 0.88105);
+        mvSettings.setValue("HUF", 266.80);
+        mvSettings.setValue("LTL", 3.4528);
+        mvSettings.setValue("LVL", 0.7085);
+        mvSettings.setValue("PLN", 4.0399);
+        mvSettings.setValue("RON", 4.1043);
+        mvSettings.setValue("SEK", 10.1430);
+        mvSettings.setValue("CHF", 1.4756);
+        mvSettings.setValue("NOK", 8.1430);
+        mvSettings.setValue("HRK", 7.2890);
+        mvSettings.setValue("RUB", 42.5015);
+        mvSettings.setValue("TRY", 2.0900);
+        mvSettings.setValue("AUD", 1.5547);
+        mvSettings.setValue("BRL", 2.5438);
+        mvSettings.setValue("CAD", 1.4752);
+        mvSettings.setValue("CNY", 9.8130);
+        mvSettings.setValue("HKD", 11.1536);
+        mvSettings.setValue("IDR", 65.7000);
+        mvSettings.setValue("KRW", 1614.29);
+        mvSettings.setValue("MXN", 18.2790);
+        mvSettings.setValue("MYR", 4.8002);
+        mvSettings.setValue("NZD", 1.9497);
+        mvSettings.setValue("PHP", 65.867);
+        mvSettings.setValue("SGD", 1.9984);
+        mvSettings.setValue("THB", 47.244);
+        mvSettings.setValue("ZAR", 10.6588);
+    }
+
+}
+
 void MainWindow::updateValue(int actionType)
 {
     double currentValue = ui->lineEdit->text().toDouble();
@@ -68,14 +101,27 @@ void MainWindow::updateValue(int actionType)
         break;
     }
 
+    QString labelText = ui->label->text();
+    QString formatRate;
+    float addRate;
+
+
     switch (actionType) {
     case 5:
-        mvTotal += mvTotal / 100 * mvSettings.value("TipRate").toInt();
+        addRate = mvTotal / 100 * mvSettings.value("TipRate").toDouble();
+        mvTotal += addRate;
         mvAction = 0;
+        formatRate.setNum(addRate, 'f', 2);
+        labelText = "Tip " + formatRate;
+        ui->labelSmall->setText(labelText);
         break;
     case 6:
-        mvTotal += mvTotal / 100 * mvSettings.value("TaxRate").toInt();
+        addRate = mvTotal / 100 * mvSettings.value("TaxRate").toDouble();
+        mvTotal += addRate;
         mvAction = 0;
+        formatRate.setNum(addRate, 'f', 2);
+        labelText = "Tax " + formatRate;
+        ui->labelSmall->setText(labelText);
         break;
     default:
         mvAction = actionType;
@@ -93,6 +139,13 @@ void MainWindow::updateScreen(int valueType)
         ui->lineEdit->clear();
     }
 
+    if (mvUpdated) {
+        ui->label->clear();
+        mvUpdated = false;
+    }
+
+    ui->labelSmall->clear();
+
     switch (valueType) {
     case 0:
         ui->lineEdit->insert("0");
@@ -132,6 +185,8 @@ void MainWindow::updateScreen(int valueType)
         break;
     case 12:
         ui->lineEdit->clear();
+        ui->label->clear();
+        ui->labelSmall->clear();
         mvTotal = 0;
         break;
     }
@@ -174,43 +229,54 @@ void MainWindow::convertCurrency(QString fromCurrency, QString toCurrency)
     }
 
     mvTotal = currentValue;
+    ui->labelSmall->clear();
     ui->lineEdit->setText(QString::number(mvTotal, 'f', 2));
+    mvClear = true;
 }
 
 void MainWindow::updateCurrency()
 {
-    mvSettings.setValue("USD", 1.4374);
-    mvSettings.setValue("JPY", 130.76);
-    mvSettings.setValue("BGN", 1.9558);
-    mvSettings.setValue("CZK", 25.947);
-    mvSettings.setValue("DKK", 7.4420);
-    mvSettings.setValue("EEK", 15.6466);
-    mvSettings.setValue("GBP", 0.88105);
-    mvSettings.setValue("HUF", 266.80);
-    mvSettings.setValue("LTL", 3.4528);
-    mvSettings.setValue("LVL", 0.7085);
-    mvSettings.setValue("PLN", 4.0399);
-    mvSettings.setValue("RON", 4.1043);
-    mvSettings.setValue("SEK", 10.1430);
-    mvSettings.setValue("CHF", 1.4756);
-    mvSettings.setValue("NOK", 8.1430);
-    mvSettings.setValue("HRK", 7.2890);
-    mvSettings.setValue("RUB", 42.5015);
-    mvSettings.setValue("TRY", 2.0900);
-    mvSettings.setValue("AUD", 1.5547);
-    mvSettings.setValue("BRL", 2.5438);
-    mvSettings.setValue("CAD", 1.4752);
-    mvSettings.setValue("CNY", 9.8130);
-    mvSettings.setValue("HKD", 11.1536);
-    mvSettings.setValue("IDR", 65.7000);
-    mvSettings.setValue("KRW", 1614.29);
-    mvSettings.setValue("MXN", 18.2790);
-    mvSettings.setValue("MYR", 4.8002);
-    mvSettings.setValue("NZD", 1.9497);
-    mvSettings.setValue("PHP", 65.867);
-    mvSettings.setValue("SGD", 1.9984);
-    mvSettings.setValue("THB", 47.244);
-    mvSettings.setValue("ZAR", 10.6588);
+    QNetworkAccessManager manager;
+    QEventLoop loop;
+    QTimer *timer = new QTimer(this);
+    QNetworkRequest *request = new QNetworkRequest(QUrl("http://www.ecb.europa.eu/stats/eurofxref/eurofxref-daily.xml"));
+    QNetworkReply *reply = manager.get(*request);
+
+    connect(reply, SIGNAL(finished()), &loop, SLOT(quit()));
+    connect(timer, SIGNAL(timeout()), &loop, SLOT(quit()));
+
+    ui->label->setText("Updating...");
+
+    loop.exec();
+    timer->start(10000);
+    xml.clear();
+    xml.addData(reply->readAll());
+ 
+    delete reply;
+
+    while (!xml.atEnd()) {
+        if (xml.isStartElement()) {
+            if (xml.name() == "Cube") {
+                QXmlStreamAttributes attrs = xml.attributes();
+                QStringRef currencyTime = attrs.value("time");
+                QStringRef currencyName = attrs.value("currency");
+                QStringRef currencyRate = attrs.value("rate");
+                if (!currencyTime.isEmpty()) {
+                    mvSettings.setValue("CurrencyTime", currencyTime.toString());
+                }
+                if (!currencyName.isEmpty()) {
+                    mvSettings.setValue(currencyName.toString(), currencyRate.toString());
+                }
+            }
+        }
+        xml.readNext();
+    }
+    
+    QDate date = mvSettings.value("CurrencyTime").toDate();
+    QString updated = date.toString();
+
+    ui->label->setText(updated);
+    mvUpdated = true;
 }
 
 void MainWindow::updateButtons()
@@ -331,6 +397,7 @@ void MainWindow::on_pushButton_Currency1_clicked()
     QString currency1 = mvSettings.value("Currency1").toString();
     QString currency2 = mvSettings.value("Currency2").toString();
     convertCurrency(currency1, currency2);
+    ui->label->setText(currency2);
 }
 
 void MainWindow::on_pushButton_Currency2_clicked()
@@ -338,6 +405,7 @@ void MainWindow::on_pushButton_Currency2_clicked()
     QString currency1 = mvSettings.value("Currency1").toString();
     QString currency2 = mvSettings.value("Currency2").toString();
     convertCurrency(currency2, currency1);
+    ui->label->setText(currency1);
 }
 
 void MainWindow::on_pushButton_SetCurrency_clicked()
@@ -363,3 +431,10 @@ void MainWindow::on_actionDonate_triggered()
 {
     QDesktopServices::openUrl(QUrl("https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=sascha.makela@gmail.com&lc=LT&item_name=STM%20Software%20-%20Currency%20Converter&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donateCC_LG%2egif%3aNonHosted"));
 }
+
+void MainWindow::on_pushButton_Update_clicked()
+{
+    ui->lineEdit->clear();
+    ui->labelSmall->clear();
+    updateCurrency();
+}
